# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.feature_store.serving import management_pb2 as qwak_dot_feature__store_dot_serving_dot_management__pb2


class FeaturesetManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFeaturesetMemoryUsageById = channel.unary_unary(
                '/com.qwak.ai.feature.store.serving.api.FeaturesetManagementService/GetFeaturesetMemoryUsageById',
                request_serializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdResponse.FromString,
                )
        self.GetFeaturesetMemoryUsageByEnvironment = channel.unary_unary(
                '/com.qwak.ai.feature.store.serving.api.FeaturesetManagementService/GetFeaturesetMemoryUsageByEnvironment',
                request_serializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentRequest.SerializeToString,
                response_deserializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentResponse.FromString,
                )


class FeaturesetManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFeaturesetMemoryUsageById(self, request, context):
        """get memory usage for a single Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturesetMemoryUsageByEnvironment(self, request, context):
        """get memory usage stats for an entire env
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeaturesetManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFeaturesetMemoryUsageById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesetMemoryUsageById,
                    request_deserializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdResponse.SerializeToString,
            ),
            'GetFeaturesetMemoryUsageByEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesetMemoryUsageByEnvironment,
                    request_deserializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentRequest.FromString,
                    response_serializer=qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.qwak.ai.feature.store.serving.api.FeaturesetManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeaturesetManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFeaturesetMemoryUsageById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.ai.feature.store.serving.api.FeaturesetManagementService/GetFeaturesetMemoryUsageById',
            qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdRequest.SerializeToString,
            qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeaturesetMemoryUsageByEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.ai.feature.store.serving.api.FeaturesetManagementService/GetFeaturesetMemoryUsageByEnvironment',
            qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentRequest.SerializeToString,
            qwak_dot_feature__store_dot_serving_dot_management__pb2.GetFeaturesetMemoryUsageByEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
